@@ -49,10 +49,7 @@ class CipherMan:
     @classmethod
     def get_cipher_by_port(cls, port, ts_protocol, peername) -> CipherMan:
         user_query = User.list_by_port(port)
-        if user_query.count() == 1:
-            access_user = user_query.first()
-        else:
-            access_user = None
+        access_user = user_query.first() if user_query.count() == 1 else None
         return cls(
             port, access_user=access_user, ts_protocol=ts_protocol, peername=peername
         )
@@ -91,10 +88,7 @@ class CipherMan:
                 self.bf.add(salt)
 
             access_user = User.find_access_user(
-                self.user_port,
-                self.method,
-                self.ts_protocol,
-                first_data,
+                self.user_port, self.method, self.ts_protocol, first_data
             )
 
             if not access_user:
@@ -105,7 +99,7 @@ class CipherMan:
                 raise RuntimeError(f"access user not have traffic: {access_user}")
             self.access_user = access_user
             self.record_user_ip(self.peername)
-            self.incr_user_tcp_num(1)
+            self.incr_user_tcp_num()
             data = bytes(self._buffer)
         if not self.cipher:
             self.cipher = self.cipher_cls(self.access_user.password)
@@ -116,8 +110,10 @@ class CipherMan:
         else:
             return self.cipher_cls(self.access_user.password).unpack(data)
 
-    def incr_user_tcp_num(self, num: int):
-        self.access_user and self.access_user.incr_tcp_conn_num(num)
+    def incr_user_tcp_num(self, num: int = 1):
+        self.ts_protocol == flag.TRANSPORT_TCP and self.access_user and self.access_user.incr_tcp_conn_num(
+            num
+        )
 
     def record_user_ip(self, peername):
         self.access_user and self.access_user.record_ip(peername)
