@@ -38,20 +38,9 @@ class LocalHandler:
         self._remote = None
         self._transport = None
         self._transport_protocol = None
-        self._transport_protocol_human = None
         self._is_closing = False
         self._connect_buffer = bytearray()
 
-    def _init_transport(self, transport: asyncio.Transport, peername, protocol):
-        self._stage = self.STAGE_INIT
-        self._transport = transport
-        self._peername = peername
-        self._transport_protocol = protocol
-        if protocol == flag.TRANSPORT_TCP:
-            self._transport_protocol_human = "tcp"
-        else:
-            self._transport_protocol_human = "udp"
-
     def close(self):
         self._stage = self.STAGE_DESTROY
         if self._is_closing:
@@ -73,8 +62,11 @@ class LocalHandler:
         else:
             self._transport.sendto(data, self._peername)
 
-    def handle_connection_made(self, transport_protocol, transport, peername):
-        self._init_transport(transport, peername, transport_protocol)
+    def handle_connection_made(self, transport, peername, protocol):
+        self._stage = self.STAGE_INIT
+        self._transport = transport
+        self._peername = peername
+        self._transport_protocol = protocol
 
     def handle_eof_received(self):
         self.close()
@@ -92,7 +84,7 @@ class LocalHandler:
             data = self.cipher.decrypt(data)
         except Exception as e:
             logging.warning(
-                f"decrypt data error:{e} remote:{self._peername},type:{self._transport_protocol_human} closing..."
+                f"decrypt data error:{e} remote:{self._peername},type:{self._transport_protocol}"
             )
             self.close()
             return
@@ -112,19 +104,20 @@ class LocalHandler:
             self.close()
         else:
             logging.warning(f"unknown stage:{self._stage}")
+            self.close()
 
     async def _handle_stage_init(self, data):
         atype, dst_addr, dst_port, header_length = parse_header(data)
         if not all([atype, dst_addr, dst_port, header_length]):
             logging.warning(
-                f"parse_header_error atype: {flag.get_atype_for_human(atype)} port: {self.port}"
+                f"parse_header_error atype={flag.get_atype_for_human(atype)} port={self.port}"
             )
             self.close()
             return
         else:
             logging.info(
-                "parse_header_success atype: {} {} from: {} dst: {}:{}".format(
-                    self._transport_protocol_human,
+                "parse_header_success flag={} atype={} from={} dst={}:{}".format(
+                    self._transport_protocol,
                     flag.get_atype_for_human(atype),
                     f"{self._peername[0]}:{self._peername[1]}",
                     dst_addr,
@@ -159,10 +152,10 @@ class LocalHandler:
                 _, remote_udp = await asyncio.wait_for(task, 5)
             except Exception as e:
                 self._stage = self.STAGE_ERROR
-                self.close()
                 logging.warning(
                     f"connection_failed, {type(e)} e: {dst_addr}:{dst_port}"
                 )
+                self.close()
             else:
                 self._remote = remote_udp
                 self._stage = self.STAGE_STREAM
@@ -213,7 +206,7 @@ class LocalTCP(asyncio.Protocol):
     def connection_made(self, transport):
         self._transport = transport
         peername = self._transport.get_extra_info("peername")
-        self._handler.handle_connection_made(flag.TRANSPORT_TCP, transport, peername)
+        self._handler.handle_connection_made(transport, peername, flag.TRANSPORT_TCP)
         CONNECTION_MADE_COUNT.inc()
         ACTIVE_CONNECTION_COUNT.inc()
 
@@ -289,8 +282,7 @@ class LocalUDP(asyncio.DatagramProtocol):
         self._transport = None
 
     def __call__(self):
-        local = LocalUDP(self.port)
-        return local
+        return LocalUDP(self.port)
 
     def connection_made(self, transport):
         self._transport = transport
@@ -302,7 +294,7 @@ class LocalUDP(asyncio.DatagramProtocol):
             handler = LocalHandler(self.port)
             self.udpmap[peername] = handler
             handler.handle_connection_made(
-                flag.TRANSPORT_UDP, self._transport, peername
+                self._transport, peername, flag.TRANSPORT_UDP
             )
         handler.handle_data_received(data)
         # NOTE 注入这个udp上次使用的时间
@@ -311,16 +303,18 @@ class LocalUDP(asyncio.DatagramProtocol):
 
     def clean_udpmap(self):
         now = time.time()
-        need_delete = []
-        for peer, handler in self.udpmap.items():
-            if now - handler.last_use_time > 1:
-                need_delete.append(peer)
+        need_delete = [
+            peer
+            for peer, handler in self.udpmap.items()
+            if now - handler.last_use_time > 1
+        ]
+
         if not need_delete:
             return
         for peer in need_delete:
             h = self.udpmap.pop(peer)
             h.close()
-        logging.info(f"clean udpmap peer: {need_delete}")
+        logging.info(f"clean udpmap peer delete={need_delete}")
 
     def error_received(self, exc) -> None:
         return super().error_received(exc)
